CloudWatch Logs — boto v2.31.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.31.0 »

# CloudWatch Logs

## boto.logs

`boto.logs.` `connect_to_region`(region_name, **kw_params)

`boto.logs.` `regions`()

  Get all available regions for the Amazon Kinesis service.

  Return type: | list
  Returns: | A list of `boto.regioninfo.RegionInfo`

## boto.logs.layer1

class `boto.logs.layer1.` `CloudWatchLogsConnection`(**kwargs)

  Amazon CloudWatch Logs Service API Reference This is the Amazon CloudWatch Logs API Reference . Amazon CloudWatch Logs is a managed service for real time monitoring and archival of application logs. This guide provides detailed information about Amazon CloudWatch Logs actions, data types, parameters, and errors. For detailed information about Amazon CloudWatch Logs features and their associated API calls, go to the `Amazon CloudWatch Logs Developer Guide`_.

  Use the following links to get started using the Amazon CloudWatch API Reference :

  - `Actions`_: An alphabetical list of all Amazon CloudWatch Logs actions.
  - `Data Types`_: An alphabetical list of all Amazon CloudWatch Logs data types.
  - `Common Parameters`_: Parameters that all Query actions can use.
  - `Common Errors`_: Client and server errors that all actions can return.
  - `Regions and Endpoints`_: Itemized regions and endpoints for all AWS products.

  In addition to using the Amazon CloudWatch Logs API, you can also use the following SDKs and third-party libraries to access Amazon CloudWatch Logs programmatically.

  - `AWS SDK for Java Documentation`_
  - `AWS SDK for .NET Documentation`_
  - `AWS SDK for PHP Documentation`_
  - `AWS SDK for Ruby Documentation`_

  Developers in the AWS developer community also provide their own libraries, which you can find at the following AWS developer centers:

  - `AWS Java Developer Center`_
  - `AWS PHP Developer Center`_
  - `AWS Python Developer Center`_
  - `AWS Ruby Developer Center`_
  - `AWS Windows and .NET Developer Center`_
  `APIVersion` = '2014-03-28'
  `DefaultRegionEndpoint` = 'logs.us-east-1.amazonaws.com'
  `DefaultRegionName` = 'us-east-1'
  `ResponseError`

    alias of `JSONResponseError`

  `ServiceName` = 'CloudWatchLogs'
  `TargetPrefix` = 'Logs_20140328'
  `create_log_group`(log_group_name)

    Creates a new log group with the specified name. The name of the log group must be unique within a region for an AWS account. You can create up to 100 log groups per account.

    You must use the following guidelines when naming a log group:

    - Log group names can be between 1 and 512 characters long.
    - Allowed characters are az, AZ, 09, ‘_’ (underscore), ‘-‘ (hyphen), ‘/’ (forward slash), and ‘.’ (period).

    Log groups are created with a default retention of 14 days. The retention attribute allow you to configure the number of days you want to retain log events in the specified log group. See the SetRetention operation on how to modify the retention of your log groups.

    Parameters: | log_group_name (string) –

  `create_log_stream`(log_group_name, log_stream_name)

    Creates a new log stream in the specified log group. The name of the log stream must be unique within the log group. There is no limit on the number of log streams that can exist in a log group.

    You must use the following guidelines when naming a log stream:

    - Log stream names can be between 1 and 512 characters long.
    - The ‘:’ colon character is not allowed.

    Parameters: | log_group_name (string) – log_stream_name (string) –

  `delete_log_group`(log_group_name)

    Deletes the log group with the specified name. Amazon CloudWatch Logs will delete a log group only if there are no log streams and no metric filters associated with the log group. If this condition is not satisfied, the request will fail and the log group will not be deleted.

    Parameters: | log_group_name (string) –

  `delete_log_stream`(log_group_name, log_stream_name)

    Deletes a log stream and permanently deletes all the archived log events associated with it.

    Parameters: | log_group_name (string) – log_stream_name (string) –

  `delete_metric_filter`(log_group_name, filter_name)

    Deletes a metric filter associated with the specified log group.

    Parameters: | log_group_name (string) – filter_name (string) – The name of the metric filter.

  `delete_retention_policy`(log_group_name)

    Parameters: | log_group_name (string) –

  `describe_log_groups`(log_group_name_prefix=None, next_token=None, limit=None)

    Returns all the log groups that are associated with the AWS account making the request. The list returned in the response is ASCII-sorted by log group name.

    By default, this operation returns up to 50 log groups. If there are more log groups to list, the response would contain a nextToken value in the response body. You can also limit the number of log groups returned in the response by specifying the limit parameter in the request.

    Parameters: | log_group_name_prefix (string) – next_token (string) – A string token used for pagination that points to the next page of results. It must be a value obtained from the response of the previous DescribeLogGroups request. limit (integer) – The maximum number of items returned in the response. If you don’t specify a value, the request would return up to 50 items.

  `describe_log_streams`(log_group_name, log_stream_name_prefix=None, next_token=None, limit=None)

    Returns all the log streams that are associated with the specified log group. The list returned in the response is ASCII-sorted by log stream name.

    By default, this operation returns up to 50 log streams. If there are more log streams to list, the response would contain a nextToken value in the response body. You can also limit the number of log streams returned in the response by specifying the limit parameter in the request.

    Parameters: | log_group_name (string) – log_stream_name_prefix (string) – next_token (string) – A string token used for pagination that points to the next page of results. It must be a value obtained from the response of the previous DescribeLogStreams request. limit (integer) – The maximum number of items returned in the response. If you don’t specify a value, the request would return up to 50 items.

  `describe_metric_filters`(log_group_name, filter_name_prefix=None, next_token=None, limit=None)

    Returns all the metrics filters associated with the specified log group. The list returned in the response is ASCII-sorted by filter name.

    By default, this operation returns up to 50 metric filters. If there are more metric filters to list, the response would contain a nextToken value in the response body. You can also limit the number of metric filters returned in the response by specifying the limit parameter in the request.

    Parameters: | log_group_name (string) – filter_name_prefix (string) – The name of the metric filter. next_token (string) – A string token used for pagination that points to the next page of results. It must be a value obtained from the response of the previous DescribeMetricFilters request. limit (integer) – The maximum number of items returned in the response. If you don’t specify a value, the request would return up to 50 items.

  `get_log_events`(log_group_name, log_stream_name, start_time=None, end_time=None, next_token=None, limit=None, start_from_head=None)

    Retrieves log events from the specified log stream. You can provide an optional time range to filter the results on the event timestamp.

    By default, this operation returns as much log events as can fit in a response size of 1MB, up to 10,000 log events. The response will always include a nextForwardToken and a nextBackwardToken in the response body. You can use any of these tokens in subsequent GetLogEvents requests to paginate through events in either forward or backward direction. You can also limit the number of log events returned in the response by specifying the limit parameter in the request.

    Parameters: | log_group_name (string) – log_stream_name (string) – start_time (long) – A point in time expressed as the number milliseconds since Jan 1, 1970 00:00:00 UTC. end_time (long) – A point in time expressed as the number milliseconds since Jan 1, 1970 00:00:00 UTC. next_token (string) – A string token used for pagination that points to the next page of results. It must be a value obtained from the nextForwardToken or nextBackwardToken fields in the response of the previous GetLogEvents request. limit (integer) – The maximum number of log events returned in the response. If you don’t specify a value, the request would return as much log events as can fit in a response size of 1MB, up to 10,000 log events. start_from_head (boolean) –

  `make_request`(action, body)
  `put_log_events`(log_group_name, log_stream_name, log_events, sequence_token=None)

    Uploads a batch of log events to the specified log stream.

    Every PutLogEvents request must include the sequenceToken obtained from the response of the previous request. An upload in a newly created log stream does not require a sequenceToken.

    The batch of events must satisfy the following constraints:

    - The maximum batch size is 32,768 bytes, and this size is calculated as the sum of all event messages in UTF-8, plus 26 bytes for each log event.
    - None of the log events in the batch can be more than 2 hours in the future.
    - None of the log events in the batch can be older than 14 days or the retention period of the log group.
    - The log events in the batch must be in chronological ordered by their timestamp.
    - The maximum number of log events in a batch is 1,000.

    Parameters: | log_group_name (string) – log_stream_name (string) – log_events (list) – A list of events belonging to a log stream. sequence_token (string) – A string token that must be obtained from the response of the previous PutLogEvents request.

  `put_metric_filter`(log_group_name, filter_name, filter_pattern, metric_transformations)

    Creates or updates a metric filter and associates it with the specified log group. Metric filters allow you to configure rules to extract metric data from log events ingested through PutLogEvents requests.

    Parameters: | log_group_name (string) – filter_name (string) – The name of the metric filter. filter_pattern (string) – metric_transformations (list) –

  `put_retention_policy`(log_group_name, retention_in_days)

    Parameters: | log_group_name (string) – retention_in_days (integer) – Specifies the number of days you want to retain log events in the specified log group. Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 547, 730.

  `set_retention`(log_group_name, retention_in_days)

    Sets the retention of the specified log group. Log groups are created with a default retention of 14 days. The retention attribute allow you to configure the number of days you want to retain log events in the specified log group.

    Parameters: | log_group_name (string) – retention_in_days (integer) – Specifies the number of days you want to retain log events in the specified log group. Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 547, 730.

  `test_metric_filter`(filter_pattern, log_event_messages)

    Tests the filter pattern of a metric filter against a sample of log event messages. You can use this operation to validate the correctness of a metric filter pattern.

    Parameters: | filter_pattern (string) – log_event_messages (list) –

## boto.logs.exceptions

exception `boto.logs.exceptions.` `DataAlreadyAcceptedException`(status, reason, body=None, *args)

exception `boto.logs.exceptions.` `InvalidParameterException`(status, reason, body=None, *args)

exception `boto.logs.exceptions.` `InvalidSequenceTokenException`(status, reason, body=None, *args)

exception `boto.logs.exceptions.` `LimitExceededException`(status, reason, body=None, *args)

exception `boto.logs.exceptions.` `OperationAbortedException`(status, reason, body=None, *args)

exception `boto.logs.exceptions.` `ResourceAlreadyExistsException`(status, reason, body=None, *args)

exception `boto.logs.exceptions.` `ResourceInUseException`(status, reason, body=None, *args)

exception `boto.logs.exceptions.` `ResourceNotFoundException`(status, reason, body=None, *args)

exception `boto.logs.exceptions.` `ServiceUnavailableException`(status, reason, body=None, *args)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.31.0 »